@@ -113,21 +113,29 @@ sub from_datetime_and_duration {
         $dt_duration = DateTime::Duration->new( %args );
     }
     # warn "Creating span from $key => ".$dt->datetime." and $dt_duration";
-    my $other_date = $dt->clone->add_duration( $dt_duration );
-    # warn "Creating span from $key => ".$dt->datetime." and ".$other_date->datetime;
+    my $other_date;
     my $other_key;
     if ( $dt_duration->is_positive ) {
-        # check if have to invert keys
-        $key = 'after' if $key eq 'end';
-        $key = 'start' if $key eq 'before';
-        $other_key = 'before';
+        if ( $key eq 'end' || $key eq 'before' ) {
+            $other_key = 'start';
+            $other_date = $dt->clone->subtract_duration( $dt_duration );
+        }
+        else {
+            $other_key = 'before';
+            $other_date = $dt->clone->add_duration( $dt_duration );
+        }
     }
     else {
-        # check if have to invert keys
-        $other_key = 'end' if $key eq 'after';
-        $other_key = 'before' if $key eq 'start';
-        $key = 'start';
+        if ( $key eq 'end' || $key eq 'before' ) {
+            $other_key = 'start';
+            $other_date = $dt->clone->add_duration( $dt_duration );
+        }
+        else {
+            $other_key = 'before';
+            $other_date = $dt->clone->subtract_duration( $dt_duration );
+        }
     }
+    # warn "Creating span from $key => ".$dt->datetime." and ".$other_date->datetime;
     return $class->new( $key => $dt, $other_key => $other_date ); 
 }
 
@@ -365,7 +373,7 @@ A 'semi-open' span includes one of its end-dates:
    $span = DateTime::Span->from_datetimes( start => $dt1, before => $dt2 );
    $span = DateTime::Span->from_datetimes( after => $dt1, end => $dt2 );
 
-A span might have just a beginning date, or just an ending date.
+A span might have just a starting date, or just an ending date.
 These spans end, or start, in an imaginary 'forever' date:
 
    $span = DateTime::Span->from_datetimes( start => $dt1 );
@@ -415,9 +423,9 @@ scalar containing infinity.
 
 Also available as C<size()>.
 
-=item * start
+=item * start, min
 
-=item * end
+=item * end, max
 
 First or last dates in the span.
 
@@ -427,6 +435,9 @@ C<DateTime::Infinite::Future> or a C<DateTime::Infinite::Past>xs object.
 If the set ends C<before> a date C<$dt>, it returns C<$dt>. Note that
 in this case C<$dt> is not a set element - but it is a set boundary.
 
+These methods return just a I<copy> of the actual boundary value.
+If you modify the result, the set will not be modified.
+
 =cut
 
 # scalar containing either negative infinity
@@ -436,13 +447,13 @@ in this case C<$dt> is not a set element - but it is a set boundary.
 
 =item * end_is_closed
 
-Returns true if the first or last dates belong to the span ( begin <= x <= end ).
+Returns true if the first or last dates belong to the span ( start <= x <= end ).
 
 =item * start_is_open
 
 =item * end_is_open
 
-Returns true if the first or last dates are excluded from the span ( begin < x < end ).
+Returns true if the first or last dates are excluded from the span ( start < x < end ).
 
 =item * union
 
@@ -482,7 +493,7 @@ Please report bugs using rt.cpan.org
 
 =head1 AUTHOR
 
-Flavio Soibelmann Glock <fglock@pucrs.br>
+Flavio Soibelmann Glock <fglock@gmail.com>
 
 The API was developed together with Dave Rolsky and the DateTime Community.
 
